@@ -23,11 +23,15 @@ def coercion_listener(mapper, class_):
 
 def instant_defaults_listener(target, args, kwargs):
     for key, column in sa.inspect(target.__class__).columns.items():
-        if hasattr(column, 'default') and column.default is not None:
+        if (
+            hasattr(column, 'default') and
+            column.default is not None and
+            key not in kwargs
+        ):
             if callable(column.default.arg):
-                setattr(target, key, column.default.arg(target))
+                kwargs[key] = column.default.arg(target)
             else:
-                setattr(target, key, column.default.arg)
+                kwargs[key] = column.default.arg
 
 
 def force_auto_coercion(mapper=None):
@@ -65,6 +69,14 @@ def force_auto_coercion(mapper=None):
         document.background_color  # Color object
         session.commit()
 
+    A useful side-effect of this is that additional validation of data will be
+    done on the moment it is being assigned to model objects. For example
+    without auto coerction set, an invalid
+    :class:`sqlalchemy_utils.types.IPAddressType` (eg. ``10.0.0 255.255``)
+    would get through without an exception being raised. The database wouldn't
+    notice this (as most databases don't have a native type for an IP address,
+    so they're usually just stored as a string), and the ``ipaddress/ipaddr``
+    package uses a string field as well.
 
     :param mapper: The mapper which the automatic data type coercion should be
                    applied to
@@ -227,6 +239,8 @@ def auto_delete_orphans(attr):
             'The relationship argument given for auto_delete_orphans needs to '
             'have a backref relationship set.'
         )
+    if isinstance(backref, tuple):
+        backref = backref[0]
 
     @sa.event.listens_for(sa.orm.Session, 'after_flush')
     def delete_orphan_listener(session, ctx):
@@ -249,7 +263,7 @@ def auto_delete_orphans(attr):
             (
                 session.query(target_class)
                 .filter(
-                    ~getattr(target_class, attr.property.backref).any()
+                    ~getattr(target_class, backref).any()
                 )
                 .delete(synchronize_session=False)
             )
